//----------------------------------------------------------------------------------------
// dof.cpp: Contains source for objects containing degrees of freedom for unknowns
//----------------------------------------------------------------------------------------

#include "dof.H"

// Default constructor
DOF::DOF()
{
  dim=255;
  storage.clear();
  iter=0;
  iter = new DOF_iterator(this);
}

// Destructor
DOF::~DOF()
{
  if (iter!=0) delete iter;
}

// Initialize global storage for degrees of freedom
// Parameters: n_el - number of elements, n_dof number of local degrees of freedom
void DOF::InitializeGlobal(int n_el, int n_dof)
{
  assert_debug(n_el>=0 && n_dof>0 && n_dof<256);
  std::size_t new_size=n_el*n_dof;
  dim=(unsigned char)n_dof;
  iter->SetDim()=dim;
  if (storage.size()<new_size)
    storage.resize(new_size);
}

// Hot file output
std::ofstream& operator<<(std::ofstream& out, const DOF& dof)
{
  out.write((char*)&dof.storage[0], dof.storage.size()*sizeof(dof.storage[0]));
  return out;
}

// Hot file input
std::ifstream& operator>>(std::ifstream& in, DOF& dof)
{
  in.read((char*)&dof.storage[0], dof.storage.size()*sizeof(dof.storage[0]));
  return in;
}
